'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FloatTypes = exports.VerticalAlignments = exports.HorizontalAlignments = exports.Breakpoints = undefined;
exports.removeProps = removeProps;
exports.createClassName = createClassName;
exports.generalClassNames = generalClassNames;

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash.omit');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Breakpoints enumerable.
 *
 * @type {{SMALL: string, MEDIUM: string, LARGE: string, XLARGE: string, XXLARGE: string}}
 */
var Breakpoints = exports.Breakpoints = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large',
  XLARGE: 'xlarge',
  XXLARGE: 'xxlarge'
};

/**
 * Horizontal alignment enumerable.
 *
 * @type {{CENTER: string, RIGHT: string, JUSTIFY: string, SPACED: string}}
 */
var HorizontalAlignments = exports.HorizontalAlignments = {
  CENTER: 'center',
  RIGHT: 'right',
  JUSTIFY: 'justify',
  SPACED: 'spaced'
};

/**
 * Vertical alignment enumerable.
 *
 * @type {{TOP: string, MIDDLE: string, BOTTOM: string, STRETCH: string}}
 */
var VerticalAlignments = exports.VerticalAlignments = {
  TOP: 'top',
  MIDDLE: 'middle',
  BOTTOM: 'bottom',
  STRETCH: 'stretch'
};

/**
 * Float types enumerable.
 *
 * @type {{LEFT: string, CENTER: string, RIGHT: string}}
 */
var FloatTypes = exports.FloatTypes = {
  LEFT: 'left',
  CENTER: 'center',
  RIGHT: 'right'
};

/**
 * Removes properties by name.
 *
 * @param {Object} props
 * @param {Array} omitProps
 * @returns {Object}
 */
function removeProps(props, omitProps) {
  _checkTypes2.default.assert.array(omitProps, 'Argument "omitProps" must be an array.');

  return (0, _lodash2.default)(props, omitProps);
}

/**
 * Creates class names from the given arguments.
 *
 * @param {*} args
 * @returns {string}
 */
function createClassName() {
  return _classnames2.default.apply(undefined, arguments);
}

/**
 * Parses the general class names from the given properties.
 *
 * @param {Object} props
 * @returns {Object}
 */
function generalClassNames(props) {
  _checkTypes2.default.assert.maybe.boolean(props.showForMedium, 'Property "showForMedium" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.showForLarge, 'Property "showForLarge" must be a boolean.');
  _checkTypes2.default.assert.maybe.string(props.showOnlyFor, 'Property "showOnlyFor" must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.hideForMedium, 'Property "hideForMedium" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.hideForLarge, 'Property "hideForLarge" must be a boolean.');
  _checkTypes2.default.assert.maybe.string(props.hideOnlyFor, 'Property "hideOnlyFor" must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.isHidden, 'Property "isHidden" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isInvisible, 'Property "isInvisible" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.showForLandscape, 'Property "showForLandscape" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.showForPortrait, 'Property "showForPortrait" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.showForSr, 'Property "showForSr" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.showOnFocus, 'Property "showOnFocus" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isClearfix, 'Property "isClearfix" must be a boolean.');
  _checkTypes2.default.assert.maybe.string(props.float, 'Property "float" must be a string.');

  return {
    // Visibility props
    'show-for-medium': props.showForMedium,
    'show-for-large': props.showForLarge,
    'show-for-small-only': props.showOnlyFor === Breakpoints.SMALL,
    'show-for-medium-only': props.showOnlyFor === Breakpoints.MEDIUM,
    'show-for-large-only': props.showOnlyFor === Breakpoints.LARGE,
    'hide-for-medium': props.hideForMedium,
    'hide-for-large': props.hideForLarge,
    'hide-for-small-only': props.hideOnlyFor === Breakpoints.SMALL,
    'hide-for-medium-only': props.hideOnlyFor === Breakpoints.MEDIUM,
    'hide-for-large-only': props.hideOnlyFor === Breakpoints.LARGE,
    'hide': props.isHidden,
    'invisible': props.isInvisible,
    'show-for-landscape': props.showForLandscape,
    'show-for-portrait': props.showForPortrait,
    'show-for-sr': props.showForSr,
    'show-on-focus': props.showOnFocus,
    // Float props
    'clearfix': props.isClearfix,
    'float-left': props.float === FloatTypes.LEFT,
    'float-center': props.float === FloatTypes.CENTER,
    'float-right': props.float === FloatTypes.RIGHT
  };
}